@@ -30,6 +30,17 @@
 #'   "a", 1:3,
 #'   "b", 4:6
 #' )
+#' @examplesIf rlang::is_installed("dplyr") && packageVersion("dplyr") >= "1.0.5"
+#'
+#' # Use dplyr::mutate(dplyr::across(...)) to assign an explicit type
+#' tribble(
+#'   ~ a,          ~ b,          ~ c,
+#'     1, "2000-01-01",        "1.5"
+#' ) %>%
+#'   dplyr::mutate(
+#'     dplyr::across(a, as.integer),
+#'     dplyr::across(b, as.Date)
+#'   )
 tribble <- function(...) {
   data <- extract_frame_data_from_dots(...)
   turn_frame_data_into_tibble(data$frame_names, data$frame_rest)
@@ -75,6 +86,9 @@ extract_frame_data_from_dots <- function(...) {
     cnd_signal(error_tribble_needs_columns())
   }
   frame_rest <- dots[-seq_along(frame_names)]
+  if (!is.null(names(frame_rest))) {
+    cnd_signal(error_tribble_named_after_tilde())
+  }
   if (length(frame_rest) == 0L) {
     # Can't decide on type in absence of data -- use logical which is
     # coercible to all types
@@ -190,6 +204,10 @@ error_tribble_needs_columns <- function() {
   tibble_error("Must specify at least one column using the `~name` syntax.")
 }
 
+error_tribble_named_after_tilde <- function() {
+  tibble_error("When using the `~name` syntax, subsequent values must not have names.")
+}
+
 error_tribble_lhs_column_syntax <- function(lhs) {
   tibble_error(bullets(
     "All column specifications must use the `~name` syntax.",
